/**
 * JASMINe
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMSTextMessageToJasmineEvent.java 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jms.TextMessage;

import org.mule.transformers.AbstractTransformer;
import org.mule.umo.transformer.TransformerException;
import org.ow2.jasmine.event.beans.JasmineEventEB;

/**
 * Class implementing a Mule transformer to format JasmineEvent and
 * JasmineEventEB to CSV.
 */
public class JMSTextMessageToJasmineEvent extends AbstractTransformer {

    /**
     * Logger.
     */
    private final Logger logger = Logger.getLogger(this.getClass().getName());

    /**
     * Domain name.
     */
    private String domainName = null;

    /**
     * Server name.
     */
    private String serverName = null;

    /**
     * Source name
     */
    private String sourceName = null;

    /**
     * sname
     */
    private String sname = null;

    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JMSTextMessageToJasmineEvent() {
        super();
        this.registerSourceType(TextMessage.class);
        this.setReturnClass(JasmineEventEB.class);
    }

    @Override
    protected Object doTransform(final Object src, final String encoding) throws TransformerException {
        JasmineEventEB event = null;
        try {
            TextMessage textMessage = (TextMessage) src;
            String text = textMessage.getText();
            Date timestamp = new Date(textMessage.getJMSTimestamp());

            event = new JasmineEventEB(domainName, serverName, "JMS", sourceName, text, timestamp, sname);

            logger.finest("Sending event " + event);
        } catch (Exception e) {
            logger.log(Level.SEVERE, "Transformer exception", e);
            throw new TransformerException(this,e);
        }

        return event;
    }
}
